<?php
/** Kashmiri (Devanagari script) (कॉशुर)
 *
 * To improve a translation please visit https://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Rk_kaul (on ks.wikipedia.org)
 * @author VibhasKS
 */

$namespaceNames = [
	NS_MEDIA            => 'मीडिया',
	NS_SPECIAL          => 'खास',
	NS_TALK             => 'बहज़',
	NS_USER             => 'रुक्न',
	NS_USER_TALK        => 'रुक्न_बहज़',
	NS_PROJECT_TALK     => '$1_बहज़',
	NS_FILE             => 'फ़ाइल',
	NS_FILE_TALK        => 'फ़ाइल_बहज़',
	NS_MEDIAWIKI        => 'मीडियाविकि',
	NS_MEDIAWIKI_TALK   => 'मीडियाविकि_बहज़',
	NS_TEMPLATE         => 'नमॆना',
	NS_TEMPLATE_TALK    => 'नमॆना_बहज़',
	NS_HELP             => 'म॒दत',
	NS_HELP_TALK        => 'म॒दत_बहज़',
	NS_CATEGORY         => 'ज़ॉज़',
	NS_CATEGORY_TALK    => 'ज़ॉज़_बहज़',
];

$digitTransformTable = [
	'0' => '०', # &#x0966;
	'1' => '१', # &#x0967;
	'2' => '२', # &#x0968;
	'3' => '३', # &#x0969;
	'4' => '४', # &#x096a;
	'5' => '५', # &#x096b;
	'6' => '६', # &#x096c;
	'7' => '७', # &#x096d;
	'8' => '८', # &#x096e;
	'9' => '९', # &#x096f;
];

